## Contributing to Workbench

Thank you for your interest in contributing to Workbench! 

All contributions will fall under the existing project [license](https://github.com/SuperCowPowers/workbench/blob/main/LICENSE). As part of our PR Process we have an auto checklist that the contributor should try to check off and a Contributor License Agreement (CLA) will pop up (just once) if you haven't contributed before.

You can contribute by reporting bugs, suggesting features, or submitting code changes. Feel free to browse open issues or propose your own changes.
If you have any questions or need assistance, don't hesitate to reach out to us at workbench@supercowpowers.com.

We look forward to your contributions to Workbench!

<img align="right" src="docs/images/scp.png" width="180">
